pub trait HostCustomField:
Send
+ Sync
+ 'static {
type Type: CustomFieldType;
const LABEL: Option<&'static str>;
}Expand description
The source label and type expression of one custom constructor field.
HostCustomTypeArgument refers to a parameter declared by the enclosing
HostCustomSchema. Function-level generics continue to use
super::HostTypeParameter.
Required Associated Constants
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".